==> nextcloud-23.0.12p1.tgz: nextcloud/apps/twofactor_backupcodes/l10n/sl.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Za račun so uspešno ustvarjene dvo-stopenjske varnostne kode",
    "Second-factor backup codes" : "Varnostne kode druge stopnje",
    "Generate backup codes" : "Ustvari rezervne šifre",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Omogočena je dvostopenjska overitev, ni pa še ustvarjenih varnostnih kod. Uporabljajo se za obnovitev dostopa do računa v primeru neveljavnosti kode druge stopnje.",
    "Backup code" : "Varnostna koda",
    "Use backup code" : "Uporabi varnostno kodo",
    "Two factor backup codes" : "Dvostopenjske varnostne kode",
    "A two-factor auth backup codes provider" : "Ponudnik varnostnih kod za dvostopenjsko overitev",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Varnostne kode so bile uspešno ustvarjene. Uporabljeno {used} od skupno {total}.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Varnostne kode je priporočljivo shraniti oziroma natisniti, saj jih v tej obliki prebrati ne bo več mogoče.",
    "Save backup codes" : "Shrani varnostne kode",
    "Print backup codes" : "Natisni varnostne kode",
    "Regenerate backup codes" : "Osveži varnostne kode",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Z osvežitvijo varnostnih kod bo preklicana veljavnost starih.",
    "An error occurred while generating your backup codes" : "Prišlo je do namako med ustvarjanjem varnostnih kok",
    "{name} backup codes" : "Varnostne kode {name}",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Uporabite eno izmed varnostnih kod, ki ste jo shranili pri nastavljanju dvostopenjske overitve",
    "Submit" : "Pošlji"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-29.0.5.tgz: nextcloud/apps/twofactor_backupcodes/l10n/sl.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Za račun so uspešno ustvarjene dvo-stopenjske varnostne kode",
    "Second-factor backup codes" : "Varnostne kode druge stopnje",
    "Generate backup codes" : "Ustvari rezervne šifre",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Omogočena je dvostopenjska overitev, ni pa še ustvarjenih varnostnih kod. Uporabljajo se za obnovitev dostopa do računa v primeru neveljavnosti kode druge stopnje.",
    "Backup code" : "Varnostna koda",
    "Use backup code" : "Uporabi varnostno kodo",
    "Two factor backup codes" : "Dvostopenjske varnostne kode",
    "A two-factor auth backup codes provider" : "Ponudnik varnostnih kod za dvostopenjsko overitev",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Varnostne kode so bile uspešno ustvarjene. Uporabljeno {used} od skupno {total}.",
    "Save backup codes" : "Shrani varnostne kode",
    "Print backup codes" : "Natisni varnostne kode",
    "Regenerate backup codes" : "Osveži varnostne kode",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Z osvežitvijo varnostnih kod bo preklicana veljavnost starih.",
    "An error occurred while generating your backup codes" : "Prišlo je do namako med ustvarjanjem varnostnih kok",
    "{name} backup codes" : "Varnostne kode {name}",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Uporabite eno izmed varnostnih kod, ki ste jo shranili pri nastavljanju dvostopenjske overitve",
    "Submit" : "Pošlji",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Varnostne kode je priporočljivo shraniti oziroma natisniti, saj jih v tej obliki prebrati ne bo več mogoče."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
